package com.ruoyi.ss.city.mapper;

import com.ruoyi.ss.city.domain.City;

import java.util.List;

/**
 * 城市Mapper接口
 *
 * @author ruoyi
 * @date 2024-09-18
 */
public interface CityMapper
{
    /**
     * 查询城市
     *
     * @param cityId 城市主键
     * @return 城市
     */
    public City selectRlCityByCityId(Long cityId);

    /**
     * 查询城市列表
     *
     * @param rlCity 城市
     * @return 城市集合
     */
    public List<City> selectRlCityList(City rlCity);

    /**
     * 新增城市
     *
     * @param rlCity 城市
     * @return 结果
     */
    public int insertRlCity(City rlCity);

    /**
     * 修改城市
     *
     * @param rlCity 城市
     * @return 结果
     */
    public int updateRlCity(City rlCity);

    /**
     * 删除城市
     *
     * @param cityId 城市主键
     * @return 结果
     */
    public int deleteRlCityByCityId(Long cityId);

    /**
     * 批量删除城市
     *
     * @param cityIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteRlCityByCityIds(Long[] cityIds);

    /**
     * 根据地址编码查询城市
     *
     * @param adcode 需要删除的数据主键集合
     * @return 结果
     */
    City selectRlCityByAdcode(String adcode);

    /**
     * 查询所有地级市城市列表
     */
    List<City> selectAllCity(String cityName);
}
